==> libtunepimp-0.2.0.tar.gz: libtunepimp-0.2.0/lib/mp3_trm.h <==
/*----------------------------------------------------------------------------

   libtunepimp -- The MusicBrainz tagging library.  
                  Let a thousand taggers bloom!
   
   Copyright (C) Robert Kaye 2003
   
   This file is part of libtunepimp.

   libtunepimp is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   libtunepimp is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with libtunepimp; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   $Id: mp3_trm.h,v 1.3 2003/06/23 09:27:19 robert Exp $

----------------------------------------------------------------------------*/
#ifndef __MP3_TRM_H_
#define __MP3_TRM_H_

#include "../config.h"

#ifdef HAVE_LIBMAD

#include <string>
using namespace std;

#include "trm.h"

class TRMGeneratorMP3 : public TRMGenerator
{
    public:

                TRMGeneratorMP3(void) {};
       virtual ~TRMGeneratorMP3(void) {};


       /* For generate function, the duration argument can be used to either
          override the length of the file itself (if its only a partial file), or
          to retrieve the length of the file. Your options are:

            1. Pass in 0 for duration, and the function will calculate the
               duration of the file from the file. THIS MAKES THE DECODE PROCESS
               A LOT SLOWER!! The calculated duration will be placed back into
               the duration argument.
            3. Pass in a non-zero duration for the file.

          In each case, the duration passed in or returned from these functions
          is in MILLISECONDS!

       */
       virtual TRMResult generate(const string &fileName, string &sig, 
                                  unsigned long &duration);

    private:


       TRMResult generateFromFile(FILE *InputFp, string &sig, 
                                  unsigned long &duration);

};
#endif
#endif

==> libtunepimp-0.3.0.tar.gz: libtunepimp-0.3.0/lib/mp3_trm.h <==
/*----------------------------------------------------------------------------

   libtunepimp -- The MusicBrainz tagging library.  
                  Let a thousand taggers bloom!
   
   Copyright (C) Robert Kaye 2003
   
   This file is part of libtunepimp.

   libtunepimp is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   libtunepimp is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with libtunepimp; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   $Id: mp3_trm.h,v 1.4 2003/10/24 19:10:48 robert Exp $

----------------------------------------------------------------------------*/
#ifndef __MP3_TRM_H_
#define __MP3_TRM_H_

#include "../config.h"

#ifdef HAVE_LIBMAD

#include <string>
using namespace std;

#include "trm.h"

class TRMGeneratorMP3 : public TRMGenerator
{
    public:

                TRMGeneratorMP3(TunePimp *tunepimp) : TRMGenerator(tunepimp) {};
       virtual ~TRMGeneratorMP3(void) {};


       /* For generate function, the duration argument can be used to either
          override the length of the file itself (if its only a partial file), or
          to retrieve the length of the file. Your options are:

            1. Pass in 0 for duration, and the function will calculate the
               duration of the file from the file. THIS MAKES THE DECODE PROCESS
               A LOT SLOWER!! The calculated duration will be placed back into
               the duration argument.
            3. Pass in a non-zero duration for the file.

          In each case, the duration passed in or returned from these functions
          is in MILLISECONDS!

       */
       virtual TRMResult generate(const string &fileName, string &sig, 
                                  unsigned long &duration);

    private:


       TRMResult generateFromFile(FILE *InputFp, string &sig, 
                                  unsigned long &duration);

};
#endif
#endif
